==> update_3.x_2.15.0.zip: components/com_pixelcms_articles/views/pixelcms_articles/tmpl/default_listing.php <==
<?php
    $CMS_URL = 'https://cms.pixel-kraft.de';

    $html[] = ($this->params->get('show_page_heading')) ? "<div class=\"page-header\"><h2 itemprop=\"headline\">{$this->category->title}</h2></div>" : "";

    foreach ($this->article as $article) {
        $html[] = "<div class='cms_article'>";
        $link = JRoute::_("index.php?option=com_pixelcms_articles&view=pixelcms_articles&articleId=$article->id&Itemid=$this->item_id");
	    if ($article->titleimage) {
		    $thumb = $this->getThumbnail($article->titleimage->url, 500, false);
            if (in_array((int) $this->params->get('cut_images'), [1, 2])) {
                $html[] = "<a href='$link' class='cms_article__image' style='background-image: url({$this->cms_url}$thumb)'></a>";
            } else {
                $html[] = "<a href='$link' class='cms_article__image'><img src='{$this->cms_url}$thumb'></a>";
            }
        } else if ($article->images) {
		    $thumb = $this->getThumbnail($article->images[0]->url, 500, false);
		    if (in_array((int) $this->params->get('cut_images'), [1, 2])) {
                $html[] = "<a href='$link' class='cms_article__image cms_article__image--article-image' style='background-image: url({$this->cms_url}$thumb)'></a>";
            } else {
                $html[] = "<a href='$link' class='cms_article__image cms_article__image--article-image'><img src='{$this->cms_url}$thumb'></a>";
            }
	    } else {
	        $html[] = "<div class='cms_article__image cms_article__image--empty'></div>";
        }
        $html[] = "<div>";

        $date = "<span class='cms_article__date'>" . DateTime::createFromFormat('Y-m-d H:i:s', $article->created_at)->format('d.m.Y') . "</span>";

        if ($this->params->get('show_date', 0) === 'before') {
            $html[] = $date;
        }
        $html[] = "<a href='$link'><h2 class='cms_article__headline'>$article->title</h2></a>";
        if ($this->params->get('show_date', 0) === 'after') {
            $html[] = $date;
        }

        $intro_text = $this->getIntro($article->content, $this->params->get('intro_length'));

	    $html[] = "<div class='cms_article__intro'>$intro_text</div>";
        $html[] = "<a class=\"cms_article__readmore\" href=\"$link\">Weiterlesen</a>";
        $html[] = "</div>";
        $html[] = "</div>";
    }
    if (!$this->article) {
         $html[] = '&nbsp;'; // Fix empty joomla modules
    }

    echo implode("\n", $html);

==> update_3.x_2.15.3.zip: components/com_pixelcms_articles/views/pixelcms_articles/tmpl/default_listing.php <==
<?php
    $CMS_URL = 'https://cms.pixel-kraft.de';

    $html[] = ($this->params->get('show_page_heading')) ? "<div class=\"page-header\"><h2 itemprop=\"headline\">{$this->category->title}</h2></div>" : "";

    foreach ($this->article as $article) {
        $classList['show_date'] = $this->params->get('show_date', '');

        $html[] = "<div class='cms_article {$this->compileClassList($classList)}'>";
        $link = JRoute::_("index.php?option=com_pixelcms_articles&view=pixelcms_articles&articleId=$article->id&Itemid=$this->item_id");
	    if ($article->titleimage) {
		    $thumb = $this->getThumbnail($article->titleimage->url, 500, false);
            if (in_array((int) $this->params->get('cut_images'), [1, 2])) {
                $html[] = "<a href='$link' class='cms_article__image' style='background-image: url({$this->cms_url}$thumb)'></a>";
            } else {
                $html[] = "<a href='$link' class='cms_article__image'><img src='{$this->cms_url}$thumb'></a>";
            }
        } else if ($article->images) {
		    $thumb = $this->getThumbnail($article->images[0]->url, 500, false);
		    if (in_array((int) $this->params->get('cut_images'), [1, 2])) {
                $html[] = "<a href='$link' class='cms_article__image cms_article__image--article-image' style='background-image: url({$this->cms_url}$thumb)'></a>";
            } else {
                $html[] = "<a href='$link' class='cms_article__image cms_article__image--article-image'><img src='{$this->cms_url}$thumb'></a>";
            }
	    } else {
	        $html[] = "<div class='cms_article__image cms_article__image--empty'></div>";
        }
        $html[] = "<div>";

        $date = "<span class='cms_article__date'>" . DateTime::createFromFormat('Y-m-d H:i:s', $article->created_at)->format('d.m.Y') . "</span>";

        if ($this->params->get('show_date', 0) === 'before') {
            $html[] = $date;
        }
        $html[] = "<a href='$link'><h2 class='cms_article__headline'>$article->title</h2></a>";
        if ($this->params->get('show_date', 0) === 'after') {
            $html[] = $date;
        }

        $intro_text = $this->getIntro($article->content, $this->params->get('intro_length'));

	    $html[] = "<div class='cms_article__intro'>$intro_text</div>";
        $html[] = "<a class=\"cms_article__readmore\" href=\"$link\">Weiterlesen</a>";
        $html[] = "</div>";
        $html[] = "</div>";
    }
    if (!$this->article) {
         $html[] = '&nbsp;'; // Fix empty joomla modules
    }

    echo implode("\n", $html);
